{*************************************************************}
{-----------------------------------------------------------------------}
{                                                                       }
{           Subprogram Name:                                            }
{           Purpose:          Ancestromania GPL                         }
{           Source Language:  Francais                                  }
{           Auteurs :                                                   }
{    Copyright Matthieu Giroux from 2013 to 2016 (LAZARUS),             }
{    Copyright Andr? Langlet (2003 to 2013),                            }
{    Copyright Philippe Cazaux-Moutou (Old Ancestro 2013 GPL)           }
{                                                                       }
{-----------------------------------------------------------------------}
{                                                                       }
{           Description:                                                }
{           Ancestromania est un Logiciel Libre.                        }
{                                                                       }
{ This program is free software: you can redistribute it and/or modify  }
{ it under the terms of the GNU General Public License as published by  }
{ the Free Software Foundation, either version 3 of the License, or     }
{ (at your option) any later version.                                   }
{                                                                       }
{ This program is distributed in the hope that it will be useful,       }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of        }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         }
{ GNU General Public License for more details.                          }
{                                                                       }
{ You should have received a copy of the GNU General Public License     }
{ along with this program.  If not, see <http://www.gnu.org/licenses/>. }
{-----------------------------------------------------------------------}

{            URLLink Components for Delphi 16/32              }
{ Version:   1.00                                             }
{ E-Mail:    info@utilmind.com                                }
{ Home Page: http://www.utilmind.com                          }
{ Created:   July, 16, 1998                                   }
{ Modified:  July, 16, 1998                                   }
{ Legal:     Copyright (c) 1999, UtilMind Solutions           }
{*************************************************************}

unit URLLink;

interface
{$IFDEF FPC}
  {$MODE Delphi}
{$ENDIF}

uses
  {$IFDEF FPC}
  LCLType, LMessages,
  {$ELSE}
  {$IFDEF WIN32} Windows, {$ELSE} WinTypes, WinProcs, {$ENDIF} ShellAPI,
  {$ENDIF}
  Messages, Classes, Graphics, Controls, StdCtrls;

type
  TURLLink = class(TLabel)
  private
    FFocusFont, FSaveFont: TFont;
    FOnMouseEnter, FOnMouseLeave:TNotifyEvent;
    procedure SetFocusFont(Value: TFont);
  protected
    procedure CMMouseEnter(var Msg: {$IFDEF FPC}TLMessage{$ELSE}TMessage{$ENDIF}); message {$IFDEF FPC}LM_MouseEnter{$ELSE}CM_MouseEnter{$ENDIF};
    procedure CMMouseLeave(var Msg: {$IFDEF FPC}TLMessage{$ELSE}TMessage{$ENDIF}); message {$IFDEF FPC}LM_MouseLeave{$ELSE}CM_MouseLeave{$ENDIF};
  public
    constructor Create(aOwner : TComponent); override;
    destructor Destroy; override;
  published
    property FocusFont: TFont read FFocusFont write SetFocusFont;
    property OnMouseEnter: TNotifyEvent read FOnMouseEnter write FOnMouseEnter;
    property OnMouseLeave: TNotifyEvent read FOnMouseLeave write FOnMouseLeave;
  end;

procedure Register;

implementation

constructor TURLLink.Create(aOwner: TComponent);
begin
  inherited Create(aOwner);
  FFocusFont := TFont.Create;
  FSaveFont := TFont.Create;
  FSaveFont.Assign(Font);
end;

destructor TURLLink.Destroy;
begin
  inherited Destroy;
  FSaveFont.Destroy;
  FFocusFont.Destroy;
end;

procedure TURLLink.CMMouseEnter(var Msg: TMessage);
begin
  if FSaveFont <> Font then FSaveFont.Assign(Font);
  Font.Assign(FFocusFont);
  if Assigned(FOnMouseEnter) then OnMouseEnter(Self);
end;

procedure TURLLink.CMMouseLeave(var Msg: TMessage);
begin
  Font.Assign(FSaveFont);
  if Assigned(FOnMouseLeave) then OnMouseLeave(Self);
end;

procedure TURLLink.SetFocusFont(Value: TFont);
begin
  if Value <> nil Then
    FFocusFont.Assign(Value);
end;

procedure Register;
begin
  RegisterComponents('Perso', [TURLLink]);
end;

end.
